﻿using System.Collections;
using System.Collections.Generic;
using UnityEngine;

public class BallSpawner : MonoBehaviour
{
	public GameObject ballPrefab;

	// Will be centered around 0.0f.
	private const float TOTAL_SPAWN_WIDTH_X = 9.8f;

	private const float BALLS_PER_SECOND = 10.0f;

	private int numBallsSpawned = 0;
	private float timeElapsed = 0.0f;
	private bool started = false;

	// Use this for initialization
	void Start ()
	{
		
	}
	
	// Update is called once per frame
	void Update ()
	{
		if (!started) {
			return;
		}
		SpawnBallOnTimer ();
	}

	// Offset will be along the top row, centered around x = 0.0f.
	Vector3 GetRandomOffset ()
	{
		float x = Random.value * TOTAL_SPAWN_WIDTH_X - TOTAL_SPAWN_WIDTH_X * 0.5f;
		return new Vector3 (x, 0.0f, 0.0f);
	}

	// Spawns a ball based on our ball spawn rate.
	void SpawnBallOnTimer ()
	{
		timeElapsed += Time.deltaTime;
		int expectedNumBalls = (int)Mathf.Floor (timeElapsed * BALLS_PER_SECOND);

		int ballsToSpawn = expectedNumBalls - numBallsSpawned;
		for (int i = 0; i < ballsToSpawn; i++) {
			var go = Object.Instantiate (ballPrefab, transform.position + GetRandomOffset (), Quaternion.identity);
			go.hideFlags = HideFlags.HideInHierarchy;  // Do not show in Unity GUI.
			numBallsSpawned++;
		}

		// Past one second, reset all timers so that we don't lose precision.
		if (timeElapsed > 1.0f) {
			numBallsSpawned = 0;
			timeElapsed = 0.0f;
		}
	}

	public void StartBallSpawns ()
	{
		started = true;
	}

	public void StopBallSpawns ()
	{
		started = false;
	}
}
