﻿using System.Collections;
using System.Collections.Generic;
using UnityEngine;
using UnityEngine.UI;

public class Score : MonoBehaviour
{
	// When this number of balls is scored, we're at 100%.
	private const int MAX_BALLS = 67;

	private Text text;
	private int numBalls = 0;
	private int currLevel = 0;
	private bool showingPercentage = false;

	// Use this for initialization
	void Start ()
	{
		text = GetComponent<Text> ();
	}
	
	// Update is called once per frame
	void Update ()
	{
		if (showingPercentage) {
			float percentage = GetPercentage ();
			text.text = "Level " + currLevel + " Progress: " + percentage.ToString ("0.0") + "%";
		}
	}

	// Add this number of balls to the score.
	public void IncrementBalls (int n)
	{
		numBalls += n;
	}

	// Clear the progress.
	public void ClearPercentage ()
	{
		numBalls = 0;
	}

	// Returns a number between [0.0f, 100.0f].
	public float GetPercentage ()
	{
		return Mathf.Min ((float)numBalls / MAX_BALLS, 1.0f) * 100.0f;
	}

	public void SetLevel (int level)
	{
		currLevel = level;
	}

	public void SetInstructions ()
	{
		showingPercentage = false;
		text = GetComponent<Text> ();
		text.text = "Control the tilters using the key pairs: \"QW\", \"OP\", \"ZX\", \"NM\", \"GH\".  Press [ENTER] to continue";
	}

	public void ContinuouslyShowPercentage ()
	{
		showingPercentage = true;
	}

	// Stops the percentage update
	public void SetYouWin ()
	{
		showingPercentage = false;
		text.text = "You Win! Credits: " +
		"Peter Djeu - Design and Programming, " +
		"Mat An - Music, " +
		"Press [ENTER] to restart";
	}
}
